======
ganrec
======

.. image:: https://img.shields.io/travis/XYangXRay/ganrec.svg
        :target: https://travis-ci.org/XYangXRay/ganrec

.. image:: https://img.shields.io/pypi/v/ganrec.svg
        :target: https://pypi.python.org/pypi/ganrec


Deep learning image reconstruction platform.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://XYangXRay.github.io/ganrec.

Features
--------

* TODO
